@@ -111,10 +111,10 @@ class Response(ResponseBase, swob.Response):
                 # for delete slo
                 self.is_slo = config_true_value(val)
 
-        if self.is_slo and 'etag' in headers:
+        if self.is_slo:  # and 'etag' in headers
             # Multipart uploads in AWS have ETags like
             #   <MD5(part_etag1 || ... || part_etagN)>-<number of parts>
-            if '-' not in headers['etag']:
+            if '-' not in headers.get('etag', ''):
                 if 's3_etag' in headers.get('content-type', ''):
                     # ETag was computed at upload, and saved in content-type
                     ctype, s3_etag = extract_s3_etag(headers['content-type'])
@@ -147,6 +147,7 @@ class Response(ResponseBase, swob.Response):
         resp = Response(status=sw_resp.status, headers=sw_resp.headers,
                         request=sw_resp.request, body=body, app_iter=app_iter,
                         conditional_response=sw_resp.conditional_response)
+        resp.accept_ranges = sw_resp.accept_ranges
         resp.environ.update(sw_resp.environ)
 
         return resp
